import QtQuick 2.0
import Sailfish.Silica 1.0
import harbour.tinyedit 1.0

Dialog {
    id: page
    allowedOrientations: Orientation.All

    property var editor

    FileModel {
        id: fileModel
    }

    canAccept: filename.text.length > 0

    onAccepted: {
        editor.saveFile(fileModel.filePath(filename.text))
    }

    SilicaListView {
        id: view
        model: fileModel
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: filename.top

        header: PageHeader {
            title: qsTr("Save file")
        }

        delegate: BackgroundItem {
            id: delegate

            Label {
                x: Theme.paddingLarge
                text: name + (isDir ? "/" : "")
                anchors.verticalCenter: parent.verticalCenter
                color: delegate.highlighted ? Theme.highlightColor : Theme.primaryColor
            }

            onClicked: {
                if (isDir) {
                    fileModel.cd(name)
                } else {
                    filename.text = name
                }
            }
        }
        VerticalScrollDecorator { flickable: view }
    }

    TextField {
        id: filename
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        placeholderText: qsTr("File name")
        inputMethodHints: Qt.ImhNoAutoUppercase

        EnterKey.enabled: text.length > 0
        EnterKey.iconSource: "image://theme/icon-m-enter-accept"
        EnterKey.onClicked: accept()
    }
}
