#include "tinyedit.h"

#include <sailfishapp.h>

TextFile::TextFile()
{
}

TextFile::~TextFile()
{
}

QString TextFile::getPath()
{
    return m_path;
}

void TextFile::setPath(const QString& path)
{
    m_path = path;
}

QString TextFile::load()
{
    QFile f(m_path);
    if (!f.open(QIODevice::ReadOnly | QIODevice::Text)) {
        return QString();
    }
    QString data(QString::fromLocal8Bit(f.readAll()));
    f.close();
    return data;
}

bool TextFile::save(const QString& data)
{
    QFile f(m_path);
    if (!f.open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text)) {
        return false;
    }
    f.write(data.toLocal8Bit());
    f.close();
    return true;
}

FileModel::FileModel() :
    m_dir(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation),
          QString(),
          QDir::Name |
          QDir::DirsFirst |
          QDir::IgnoreCase |
          QDir::LocaleAware,
          QDir::AllDirs |
          QDir::Files |
          QDir::NoDot),
    m_loaded(false)
{
    load();
}

FileModel::~FileModel()
{
}

void FileModel::load()
{
    if (m_loaded) return;
    m_files = m_dir.entryInfoList();
    m_loaded = true;
}

void FileModel::reset_start()
{
    beginResetModel();
    m_loaded = false;
}

void FileModel::reset_end()
{
    load();
    endResetModel();
}

QHash<int, QByteArray> FileModel::roleNames() const
{
    QHash<int, QByteArray> roles;
    roles[NameRole] = "name";
    roles[PathRole] = "path";
    roles[IsDirRole] = "isDir";
    return roles;
}

int FileModel::rowCount(const QModelIndex& parent) const
{
    if (parent.isValid())
    {
        return 0;
    }

    return m_files.size();
}

QVariant FileModel::data(const QModelIndex& index, int role) const
{
    const QFileInfo& info = m_files[index.row()];
    switch (role)
    {
    case NameRole:
        return info.fileName();
    case PathRole:
        return info.filePath();
    case IsDirRole:
        return info.isDir();
    default:
        return QVariant();
    }
}

QString FileModel::getPath()
{
    return m_dir.path();
}

void FileModel::setPath(const QString& path)
{
    reset_start();
    m_dir.setPath(path);
    reset_end();
}

void FileModel::cd(const QString& path)
{
    reset_start();
    m_dir.cd(path);
    reset_end();
}

void FileModel::mkdir(const QString& path)
{
    reset_start();
    m_dir.mkdir(path);
    reset_end();
}

QString FileModel::filePath(const QString& name) const
{
    return m_dir.filePath(name);
}

int main(int argc, char *argv[])
{
    // SailfishApp::main() will display "qml/template.qml", if you need more
    // control over initialization, you can use:
    //
    //   - SailfishApp::application(int, char *[]) to get the QGuiApplication *
    //   - SailfishApp::createView() to get a new QQuickView * instance
    //   - SailfishApp::pathTo(QString) to get a QUrl to a resource file
    //
    // To display the view, call "show()" (will show fullscreen on device).

    qmlRegisterType<TextFile>("harbour.tinyedit", 1, 0, "TextFile");
    qmlRegisterType<FileModel>("harbour.tinyedit", 1, 0, "FileModel");

    return SailfishApp::main(argc, argv);
}
